@@ -2,60 +2,63 @@ import __main__
 
 def get_version_number():
     path = __main__.os.path.abspath(__main__.os.getcwd())
-    ## grep 'version\s*=\s*' setup.py  | tr -d 'version=' | tr -d ',' | awk '{print $1}' ## get version in python
-    ##make provision to get version number from java type project
+    # grep 'version\s*=\s*' setup.py  | tr -d 'version=' | tr -d ',' | awk '{print $1}' ## get version in python
+    # make provision to get version number from java type project
     process_result = __main__.subprocess.Popen("node -p \"require('./package.json').version\"", shell=True, stdout=__main__.subprocess.PIPE, cwd=path)
     version_result = process_result.communicate()[0]
     return str(version_result, 'utf-8')
 
 def setup_variables():
-     if __main__.group_id == '':
-            __main__.group_id = __main__.os.environ.get('NEXUS_GROUP_ID')   
+    if __main__.group_id == '':
+        __main__.group_id = __main__.os.environ.get('NEXUS_GROUP_ID')   
         if __main__.group_id == '':
             print("Fail to obtain Nexus group id from environment variables")
+            return __main__.sys.exit(2)  
 
-    ## To-do: Fix artifact name
+    # To-do: Fix artifact name
     if __main__.artifact_name == '':
-       __main__.artifact_name = __main__.os.environ.get('CI_PROJECT_NAME')
-       ## Fix to add extension, right now it is just a folder
-       if __main__.artifact_name == '':
-           print("Could not obtain project name from git repository to use as artifact name")
-           return sys.exit(2)     
+        __main__.artifact_name = __main__.os.environ.get('CI_PROJECT_NAME')
+        # Fix to add extension, right now it is just a folder
+        if __main__.artifact_name == '':
+            print("Could not obtain project name from git repository to use as artifact name")
+            return __main__.sys.exit(2)     
     
     if __main__.repository_name == '':
-       __main__.branch_name = __main__.os.environ.get('CI_COMMIT_BRANCH')
-       if __main__.branch_name == '':
-           print("Could not compute repository name to store to based on branch name e.g <organization>-snapshots")
-           return sys.exit(2)
-       else:
-           if 'master' == __main__.branch_name:
-               __main__.repository_name = 'egov-releases'
-           else:
-               __main__.repository_name = 'egov-snapshots'
+        __main__.branch_name = __main__.os.environ.get('CI_COMMIT_BRANCH')
+        if __main__.branch_name == '':
+            print("Could not compute repository name to store to based on branch name e.g <organization>-snapshots")
+            return __main__.sys.exit(2)  
+        else:
+            if 'master' == __main__.branch_name:
+                __main__.repository_name = 'egov-releases'
+            else:
+                __main__.repository_name = 'egov-snapshots'
+                
     if __main__.nexus_format == 'raw' and __main__.directory == '':
         print("RAW nexus repository format requires a directory")
-        return sys.exit(2)
+        return __main__.sys.exit(2)
       
     if __main__.nexus_format == 'maven' and __main__.group_id == '':
         print("Maven2 repository requires Group ID  e.g com.<organization>.<applicationname>")
-        return sys.exit(2)
+        return __main__.sys.exit(2)
     
     if __main__.username == '':
         __main__.username = __main__.os.environ.get('NEXUS_USERNAME')
         if __main__.username == '' or __main__.username is None:
             print("Fail to retrieve Nexus username from environment variables")
-            return sys.exit(2)
+            return __main__.sys.exit(2)
     
     if __main__.password == '':
-        __main__.password = os.environ.get('NEXUS_PASSWORD')
+        __main__.password = __main__.os.environ.get('NEXUS_PASSWORD')
         if __main__.password == '' or __main__.password is None:
             print("Fail to retrieve Nexus password from environment variables")
-            return sys.exit(2)
+            return __main__.sys.exit(2)
     
     if __main__.work_directory == '':
-        __main__.work_directory = __main__.os.path.abspath(os.getcwd())
+        __main__.work_directory = __main__.os.path.abspath(__main__.os.getcwd())
         
     __main__.auth = (__main__.username, __main__.password)    
+    
     if 'service/rest' in  __main__.repository_base_url:
         __main__.repository_full_url = __main__.repository_base_url
     else: 
@@ -68,14 +71,11 @@ def upload_nexus_raw():
     finalpath = __main__.work_directory + '/' + __main__.artifact_name
     print("Uploading to Nexus Repository: "+ __main__.repository_name)
     files = {
-
-	  'raw.directory' : (None, __main__.directory),
-	  'raw.asset1' : (None, finalpath),
-	  'raw.asset1.filename': (None, __main__.artifact_name)
+        'raw.directory' : (None, __main__.directory),
+	    'raw.asset1' : (None, finalpath),
+	    'raw.asset1.filename': (None, __main__.artifact_name)
     }
-	#raw.assetN : (None, 
-	#raw.assetN.filename
-    #response = requests.post("http://localhost:8081/service/rest/v1/components",params=params, files=files, auth=auth)
+	
     response = __main__.requests.post(url=__main__.repository_full_url, params=params, files=files, proxies=__main__.proxies, auth=__main__.auth)
     if response.status_code == 204:
         print("Nexus Upload successful")
@@ -92,9 +92,9 @@ def upload_nexus_npm():
     params = (('repository', __main__.repository_name),)
     finalpath = __main__.work_directory + '/' + __main__.artifact_name
     files = {
-	  'npm.asset' : (None, finalpath),
+	    'npm.asset' : (None, finalpath),
     }
-    response = requests.post(url=__main__.repository_full_url, params=params, files=files, proxies=__main__.proxies, auth=__main__.auth)
+    response = __main__.requests.post(url=__main__.repository_full_url, params=params, files=files, proxies=__main__.proxies, auth=__main__.auth)
     if response.status_code == 204:
         print("Nexus Upload successful")
         return __main__.sys.exit(0)
@@ -105,6 +105,8 @@ def upload_nexus_npm():
 
 def upload_nexus_maven():
     actual_artifact_name = ''
+    extension = ''
+    versionnumber = ''
     
     params = (('repository', __main__.repository_name),)
    
